aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCash Costello <cash.costello@gmail.com>2012-01-21 12:44:55 -0500
committerCash Costello <cash.costello@gmail.com>2012-01-21 12:44:55 -0500
commit19a6962c819dc33a0967dcef56154f6930b52287 (patch)
treef81d3530358a4056caf12a695d0700b0c232a69d
parent8e4d4c50df3f19be4ad9c204797e57ecd9ba02b3 (diff)
downloadelgg-19a6962c819dc33a0967dcef56154f6930b52287.tar.gz
elgg-19a6962c819dc33a0967dcef56154f6930b52287.tar.bz2
Fixes #4180 finished conversion to system cache by converting datalist/CONFIG var name
-rw-r--r--documentation/info/config.php6
-rw-r--r--engine/lib/cache.php16
-rw-r--r--engine/lib/configuration.php8
-rw-r--r--engine/lib/upgrades/2012012100-1.8.3-system_cache-93100e7d55a24a11.php13
-rw-r--r--install/ElggInstaller.php2
-rw-r--r--mod/developers/views/default/admin/developers/settings.php2
-rw-r--r--version.php2
-rw-r--r--views/default/forms/admin/site/update_advanced.php2
8 files changed, 32 insertions, 19 deletions
diff --git a/engine/lib/configuration.php b/engine/lib/configuration.php
index cccd69105..772c24930 100644
--- a/engine/lib/configuration.php
+++ b/engine/lib/configuration.php
@@ -599,11 +599,11 @@ function _elgg_load_application_config() {
} else {
$CONFIG->simplecache_enabled = 1;
}
- $viewpath_cache_enabled = datalist_get('viewpath_cache_enabled');
- if ($viewpath_cache_enabled !== false) {
- $CONFIG->viewpath_cache_enabled = $viewpath_cache_enabled;
+ $system_cache_enabled = datalist_get('system_cache_enabled');
+ if ($system_cache_enabled !== false) {
+ $CONFIG->system_cache_enabled = $system_cache_enabled;
} else {
- $CONFIG->viewpath_cache_enabled = 1;
+ $CONFIG->system_cache_enabled = 1;
}
// initialize context here so it is set before the get_input call
diff --git a/engine/lib/upgrades/2012012100-1.8.3-system_cache-93100e7d55a24a11.php b/engine/lib/upgrades/2012012100-1.8.3-system_cache-93100e7d55a24a11.php
new file mode 100644
index 000000000..3a9aae2a1
--- /dev/null
+++ b/engine/lib/upgrades/2012012100-1.8.3-system_cache-93100e7d55a24a11.php
@@ -0,0 +1,13 @@
+<?php
+/**
+ * Elgg 1.8.3 upgrade 2012012100
+ * system_cache
+ *
+ * Convert viewpath cache to system cache
+ */
+
+$value = datalist_get('viewpath_cache_enabled');
+datalist_set('system_cache_enabled', $value);
+
+$query = "DELETE FROM {$CONFIG->dbprefix}datalists WHERE name='viewpath_cache_enabled'";
+delete_data($query);
diff --git a/install/ElggInstaller.php b/install/ElggInstaller.php
index d556ba744..0e75ed008 100644
--- a/install/ElggInstaller.php
+++ b/install/ElggInstaller.php
@@ -1401,7 +1401,7 @@ class ElggInstaller {
datalist_set('default_site', $site->getGUID());
datalist_set('version', get_version());
datalist_set('simplecache_enabled', 1);
- datalist_set('viewpath_cache_enabled', 1);
+ datalist_set('system_cache_enabled', 1);
// new installations have run all the upgrades
$upgrades = elgg_get_upgrade_files($submissionVars['path'] . 'engine/lib/upgrades/');
diff --git a/mod/developers/views/default/admin/developers/settings.php b/mod/developers/views/default/admin/developers/settings.php
index 519364fe1..459cbabad 100644
--- a/mod/developers/views/default/admin/developers/settings.php
+++ b/mod/developers/views/default/admin/developers/settings.php
@@ -13,7 +13,7 @@ $data = array(
'system_cache' => array(
'type' => 'checkbox',
'value' => 1,
- 'checked' => elgg_get_config('viewpath_cache_enabled') == 1,
+ 'checked' => elgg_get_config('system_cache_enabled') == 1,
),
'display_errors' => array(
diff --git a/version.php b/version.php
index 540fecac6..dc6897c18 100644
--- a/version.php
+++ b/version.php
@@ -11,7 +11,7 @@
// YYYYMMDD = Elgg Date
// XX = Interim incrementer
-$version = 2012012000;
+$version = 2012012100;
// Human-friendly version name
$release = '1.8.3';
diff --git a/views/default/forms/admin/site/update_advanced.php b/views/default/forms/admin/site/update_advanced.php
index 786feb101..b935090f0 100644
--- a/views/default/forms/admin/site/update_advanced.php
+++ b/views/default/forms/admin/site/update_advanced.php
@@ -44,7 +44,7 @@ $form_body .= "<div>" . elgg_echo('installation:systemcache:description') . "<br
$form_body .= elgg_view("input/checkboxes", array(
'options' => array(elgg_echo('installation:systemcache:label') => elgg_echo('installation:systemcache:label')),
'name' => 'system_cache_enabled',
- 'value' => (elgg_get_config('viewpath_cache_enabled') ? elgg_echo('installation:systemcache:label') : ""),
+ 'value' => (elgg_get_config('system_cache_enabled') ? elgg_echo('installation:systemcache:label') : ""),
)) . "</div>";
$debug_options = array('0' => elgg_echo('installation:debug:none'), 'ERROR' => elgg_echo('installation:debug:error'), 'WARNING' => elgg_echo('installation:debug:warning'), 'NOTICE' => elgg_echo('installation:debug:notice'));
diff --git a/documentation/info/config.php b/documentation/info/config.php
index 19e76c8ae..b45428477 100644
--- a/documentation/info/config.php
+++ b/documentation/info/config.php
@@ -218,11 +218,11 @@ $CONFIG->dataroot;
$CONFIG->simplecache_enabled;
/**
* Is view paths cache enabled
*
- * @global string $CONFIG->viewpath_cache_enabled
+ * @global string $CONFIG->system_cache_enabled
*/
-$CONFIG->viewpath_cache_enabled;
+$CONFIG->system_cache_enabled;
/**
* The site description from the current site object.
@@ -218,11 +218,11 @@ $CONFIG->dataroot;
$CONFIG->simplecache_enabled;
/**
- * Is view paths cache enabled
+ * Is the system cache enabled
*
diff --git a/engine/lib/cache.php b/engine/lib/cache.php
index b563f5ab0..75183d23a 100644
--- a/engine/lib/cache.php
+++ b/engine/lib/cache.php
@@ -54,7 +54,7 @@ function elgg_reset_system_cache() {
function elgg_save_system_cache($type, $data) {
global $CONFIG;
- if ($CONFIG->viewpath_cache_enabled) {
+ if ($CONFIG->system_cache_enabled) {
$cache = elgg_get_system_cache();
return $cache->save($type, $data);
}
@@ -71,7 +71,7 @@ function elgg_save_system_cache($type, $data) {
function elgg_load_system_cache($type) {
global $CONFIG;
- if ($CONFIG->viewpath_cache_enabled) {
+ if ($CONFIG->system_cache_enabled) {
$cache = elgg_get_system_cache();
$cached_data = $cache->load($type);
@@ -86,7 +86,7 @@ function elgg_load_system_cache($type) {
/**
* Enables the system disk cache.
*
* Uses the 'viewpath_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*
* @return void
@@ -94,15 +94,15 @@ function elgg_load_system_cache($type) {
function elgg_enable_system_cache() {
global $CONFIG;
- datalist_set('viewpath_cache_enabled', 1);
- $CONFIG->viewpath_cache_enabled = 1;
+ datalist_set('system_cache_enabled', 1);
+ $CONFIG->system_cache_enabled = 1;
elgg_reset_system_cache();
}
/**
* Disables the system disk cache.
*
* Uses the 'viewpath_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*
* @return void
@@ -110,8 +110,8 @@ function elgg_enable_system_cache() {
function elgg_disable_system_cache() {
global $CONFIG;
- datalist_set('viewpath_cache_enabled', 0);
- $CONFIG->viewpath_cache_enabled = 0;
+ datalist_set('system_cache_enabled', 0);
+ $CONFIG->system_cache_enabled = 0;
elgg_reset_system_cache();
}
@@ -86,7 +86,7 @@ function elgg_load_system_cache($type) {
* Enables the system disk cache.
*
- * Uses the 'viewpath_cache_enabled' datalist with a boolean value.
+ * Uses the 'system_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*
@@ -94,15 +94,15 @@ function elgg_load_system_cache($type) {
* Disables the system disk cache.
*
- * Uses the 'viewpath_cache_enabled' datalist with a boolean value.
+ * Uses the 'system_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*